#!/bin/sh

# Build script for crypto-modules-extra-rt
# Author: Ejis <ejis@mailoo.org>

# Homepage: Not needed


set -e


SOFTNAME=crypto-modules-extra-rt
VERSION=2.6.33.7.2.rt30
ZENVER=69
BUILD=1

CATEGORY=extra/a

MARCH=i486
FLAGS="-O2 -march=$MARCH -mtune=i686"

DOTNEW=1

CWD=$(pwd)

PKG=$SOFTNAME-$VERSION-$MARCH-$ZENVER.$BUILD

SOFTDIR=$CWD/$SOFTNAME-$VERSION
PKGDIR=$CWD/$PKG

PKGFILE=$PKGDIR.txz
MD5=$PKGDIR.md5
SRC=$PKGDIR.src
DEP=$PKGDIR.dep

SRCFILES=(
)

HOSTURL=http://zenwalk.pinguix.com/user-accounts/ejis/$CATEGORY/$SOFTNAME/$ZENVER
SRCURLS=(
)

SRCLINKS=(
)

DOC=(
)

EXTRADEPS=(
)

LESSDEPS=(
)


# Erase the previous build files

rm -rf $PKGFILE $SOFTDIR $PKGDIR $MD5 $SRC $DEP
mkdir -p $PKG


# Build

echo ""
echo "-----Building-----"
echo ""

export CFLAGS=$FLAGS
export CXXFLAGS=$FLAGS

mkdir -p $PKGDIR/lib/modules/$(uname -r)/kernel/crypto
cd /usr/src/linux-$(uname -r)
make -j2 CONFIG_CRYPTO_TWOFISH_COMMON=m \
	 CONFIG_CRYPTO_TWOFISH=m \
	 CONFIG_CRYPTO_RMD160=m \
	 CONFIG_CRYPTO_SERPENT=m \
	 CONFIG_CRYPTO_GF128MUL=m \
	 CONFIG_CRYPTO_WP512=m \
	 CONFIG_CRYPTO_XTS=m \
	 M=crypto/ || exit 1
for kmod in twofish_common twofish rmd160 serpent gf128mul wp512 xts; do
	install -m 644 crypto/${kmod}.ko $PKGDIR/lib/modules/$(uname -r)/kernel/crypto
done
cd /usr/src/linux-$(uname -r)/crypto
rm *.o
rm *.ko	


# Packaging

echo ""
echo "-----Packaging-----"
echo ""

cd $PKGDIR

mkdir -p $PKGDIR/install
mkdir -p $PKGDIR/usr/src/$SOFTNAME-$VERSION


	       #|-----handy-ruler------------------------------------------------------|
cat << EOF > $PKGDIR/install/slack-desc
$SOFTNAME: $SOFTNAME - (Extra Cryptographic Kernel RT Modules)
$SOFTNAME:
$SOFTNAME: A collection of extra cryptograhic kernel modules
$SOFTNAME: needed by some applications to work perfectly.
$SOFTNAME: 
$SOFTNAME: This package is made for kernel-rt.
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
$SOFTNAME: 
EOF


cat << EOF > $PKGDIR/install/doinst.sh
depmod -a
EOF


# Redundent

if [ -d $PKGDIR/usr/share/doc ]; then
	mv $PKGDIR/usr/share/doc/$SOFTNAME/* $PKGDIR/usr/doc/$SOFTNAME-$VERSION/
	rm -rvf $PKGDIR/usr/share/doc
fi

if [ -d $PKGDIR/etc ]; then
	if [ $DOTNEW == 1 ]; then
		find $PKGDIR/etc -type f -exec \
			mv {} {}.new \;
	fi
fi

find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null || true

if [ -d $PKGDIR/usr/man ]; then
	
	( cd $PKGDIR/usr/man
		find . -type f -exec gzip -9 {} \;
		for i in $( find . -type l ) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
	)
	
fi

if [ -d $PKGDIR/usr/info ]; then
	
	rm -f $PKGDIR/usr/info/dir
	gzip -9 $PKGDIR/usr/info/*.info*
	
fi

find . -name perllocal.pod \
	-o -name ".packlist" \
	-o -name "*.bs" \
	| xargs rm -f


cp -v $CWD/build-$SOFTNAME.sh \
	$PKGDIR/usr/src/$SOFTNAME-$VERSION/

#cp -rv	${DOC[@]} $PKGDIR/usr/doc/$SOFTNAME-$VERSION/


# fix permissions and ownership
chown -R root:root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;


/sbin/makepkg -l y -c n $PKGFILE


cd $CWD

echo 'Creating .md5 file'
md5sum $PKG.txz > $MD5

echo 'Creating .src file'
echo "$HOSTURL/build-$SOFTNAME.sh" > $SRC
#for link in ${SRCLINKS[@]}; do
#	echo $link >> $SRC
#done

echo "" > $SRC

echo 'Checking for dependencies'
deps=$(depfinder $PKGFILE)

for dep in ${EXTRADEPS[@]}; do
	deps="$deps,$dep"
done

for dep in ${LESSDEPS[@]}; do
	deps=${deps/$dep/}
done

order=$(echo ${deps//,/ } | sort -d)
echo ${order// /,} > $DEP

echo "Removing build directories"
rm -rf $SOFTDIR $PKG
